$Pages = @()

$Pages += New-UDPage -Name "Home" -Content {
    New-UDTypography -Text "This is the demo dashboard for Universal Dashboard. Check out the various pages to view all the controls. "

    New-UDButton -Text 'Download Template' -OnClick {
        Invoke-UDRedirect https://ironmansoftware.com/powershell-universal/templates
    }
}

$Pages += New-UDPage -Name 'Alerts' -Content {
    New-UDTypography 'Alerts provide a simple way to communicate information to a user.'

    New-UDAlert -Severity 'error' -Text 'This is an error alert — check it out!' 
    New-UDAlert -Severity 'warning' -Text 'This is an warning alert — check it out!'
    New-UDAlert -Severity 'info' -Text 'This is an error info — check it out!' 
    New-UDAlert -Severity 'success' -Text 'This is an success alert — check it out!'
    New-UDAlert -Severity 'error' -Content { New-UDHtml 'This is an error alert — <strong>check it out!</strong>' } -Title "Error"
New-UDAlert -Severity 'warning' -Content { New-UDHtml 'This is an warning alert — <strong>check it out!</strong>' } -Title "Warning"
New-UDAlert -Severity 'info' -Content { New-UDHtml 'This is an error info — <strong>check it out!</strong>' } -Title "Info"
New-UDAlert -Severity 'success' -Content { New-UDHtml 'This is an success alert — <strong>check it out!</strong>' } -Title "Success"
}

$Pages += New-UDPage -Name 'Chip' -Content {
    New-UDTypography 'Chips are compact elements that represent an input, attribute, or action. Chips allow users to enter information, make selections, filter content, or trigger actions. While included here as a standalone component, the most common use will be in some form of input, so some of the behavior demonstrated here is not shown in context.'

     New-UDChip -Label 'Basic'
     New-UDChip -Label 'Basic' -Icon (New-UDIcon -Icon 'user')
     New-UDChip -Label 'OnClick' -OnClick {
        Show-UDToast -Message 'Hello!'
    }
    New-UDChip -Label 'OnDelete' -OnClick {
        Show-UDToast -Message 'Goodbye!'
    }
}

$Pages += New-UDPage -Name 'DateTime' -Content {
    New-UDTypography  "The New-UDDateTime component is used for formatting dates and times within the client's browser. By using the client's browser, you can format the time based on the local time zone and locale settings for the user."

    New-UDElement -tag p -Content {
        New-UDDateTime -InputObject (Get-Date)
    }
    
    New-UDElement -tag p -Content {
        New-UDDateTime -InputObject (Get-Date) -Format 'DD/MM/YYYY'
    }
}

$Pages += New-UDPage -Name 'Icon' -Content {
    New-UDIcon -Icon 'address_book'
    New-UDIcon -Icon 'address_book' -Size 'sm'
    New-UDIcon -Icon 'address_book' -Size 'lg'
    New-UDIcon -Icon 'address_book' -Size '5x'
    New-UDIcon -Icon 'address_book' -Size '10x'
    New-UDIcon -Icon 'address_book' -Size '5x' -Rotation 90
    New-UDIcon -Icon 'address_book' -Size '5x' -Border
    New-UDIcon -Icon 'address_book' -Size '5x' -Style @{
        backgroundColor = "red"
    }

    New-UDTextbox -Id 'txtIconSearch' -Label 'Search' 
    New-UDButton -Text 'Search' -OnClick {
        Sync-UDElement -Id 'icons'
    }

    New-UDElement -tag 'p' -Content {}

    New-UDDynamic -Id 'icons' -Content {
        $Icons = [Enum]::GetNames([UniversalDashboard.Models.FontAwesomeIcons])
        $IconSearch = (Get-UDElement -Id 'txtIconSearch').value
        if ($null -ne $IconSearch -and $IconSearch -ne '')
        {
            $Icons = $Icons.where({ $_ -match $IconSearch})

            foreach($icon in $icons) {
                New-UDIcon -Icon $icon -Size lg
            }
        }
    }
}

$Pages += New-UDPage -Name 'List' -Content {
    New-UDList -Content {
        New-UDListItem -Label 'Inbox' -Icon (New-UDIcon -Icon envelope -Size 3x) -SubTitle 'New Stuff'
        New-UDListItem -Label 'Drafts' -Icon (New-UDIcon -Icon edit -Size 3x) -SubTitle "Stuff I'm working on "
        New-UDListItem -Label 'Trash' -Icon (New-UDIcon -Icon trash -Size 3x) -SubTitle 'Stuff I deleted'
        New-UDListItem -Label 'Spam' -Icon (New-UDIcon -Icon bug -Size 3x) -SubTitle "Stuff I didn't want"
    }

    New-UDList -Content {
        New-UDListItem -Label 'Inbox' -Icon (New-UDIcon -Icon envelope -Size 3x) -SubTitle 'New Stuff'
        New-UDListItem -Label 'Drafts' -Icon (New-UDIcon -Icon edit -Size 3x) -SubTitle "Stuff I'm working on "
        New-UDListItem -Label 'Trash' -Icon (New-UDIcon -Icon trash -Size 3x) -SubTitle 'Stuff I deleted'
        New-UDListItem -Label 'Spam' -Icon (New-UDIcon -Icon bug -Size 3x) -SubTitle "Stuff I didn't want" -OnClick {
            Show-UDToast -Message 'Clicked'
        }
    }
}

$Pages += New-UDPage -Name 'Table' -Content {
    $Data = @(
        @{Dessert = 'Frozen yoghurt'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Ice cream sandwich'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Eclair'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Cupcake'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Gingerbread'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
    ) 

    New-UDTable -Data $Data -Title 'Custom Simple'

    New-UDElement -Tag p

    $Data = @(
        @{Dessert = 'Frozen yoghurt'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Ice cream sandwich'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Eclair'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Cupcake'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Gingerbread'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
    ) 

    $Columns = @(
        New-UDTableColumn -Property Dessert -Title "A Dessert"
        New-UDTableColumn -Property Calories -Title Calories 
        New-UDTableColumn -Property Fat -Title Fat 
        New-UDTableColumn -Property Carbs -Title Carbs 
        New-UDTableColumn -Property Protein -Title Protein 
    )

    New-UDTable -Id 'customColumnsTable' -Data $Data -Columns $Columns -Title 'Custom Columns'

    New-UDElement -Tag p

    $Data = @(
        @{Dessert = 'Frozen yoghurt'; Calories = 1; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Ice cream sandwich'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Eclair'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Cupcake'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Gingerbread'; Calories = 200; Fat = 6.0; Carbs = 24; Protein = 4.0}
    ) 

    $Columns = @(
        New-UDTableColumn -Property Dessert -Title Dessert -Render { 
            New-UDButton -Id "btn$($EventData.Dessert)" -Text "Click for Dessert!" -OnClick { Show-UDToast -Message $EventData.Dessert } 
        }
        New-UDTableColumn -Property Calories -Title Calories 
        New-UDTableColumn -Property Fat -Title Fat 
        New-UDTableColumn -Property Carbs -Title Carbs 
        New-UDTableColumn -Property Protein -Title Protein 
    )

    New-UDTable -Data $Data -Columns $Columns -Sort -Export -Title 'Custom Rendering'

    New-UDElement -Tag p

    $Data = @(
        @{Dessert = 'Frozen yoghurt'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Ice cream sandwich'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Eclair'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Cupcake'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Gingerbread'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
    ) 

    $Columns = @(
        New-UDTableColumn -Property Dessert -Title Dessert -Render { 
            New-UDButton -Id "btn$($EventData.Dessert)" -Text "Click for Dessert!" -OnClick { Show-UDToast -Message $EventData.Dessert } 
        }
        New-UDTableColumn -Property Calories -Title Calories -Width 5 -Truncate
        New-UDTableColumn -Property Fat -Title Fat 
        New-UDTableColumn -Property Carbs -Title Carbs 
        New-UDTableColumn -Property Protein -Title Protein 
    )

    New-UDTable -Data $Data -Columns $Columns -Sort -Title 'Custom Width'
    
    New-UDElement -Tag p

    $Data = @(
        @{Dessert = 'Frozen yoghurt'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Ice cream sandwich'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Eclair'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Cupcake'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Gingerbread'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
    ) 

    $Columns = @(
        New-UDTableColumn -Property Dessert -Title "A Dessert" -Filter -FilterType AutoComplete
        New-UDTableColumn -Property Calories -Title Calories -Filter -FilterType Range
        New-UDTableColumn -Property Fat -Title Fat -Filter -FilterType Range
        New-UDTableColumn -Property Carbs -Title Carbs -Filter -FilterType Range
        New-UDTableColumn -Property Protein -Title Protein -Filter -FilterType Range
    )

    New-UDTable -Id 'customColumnsTable' -Data $Data -Columns $Columns -ShowFilter -Title 'Filters'
    
    New-UDElement -Tag p

    $Data = @(
        @{Dessert = 'Frozen yoghurt'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Ice cream sandwich'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Eclair'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Cupcake'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Gingerbread'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
    ) 

    New-UDTable -Data $Data -Paging -PageSize 2 -Title 'Paging'

    New-UDElement -Tag p

    $Data = @(
        @{Dessert = 'Frozen yoghurt'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Ice cream sandwich'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Eclair'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Cupcake'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Gingerbread'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
    ) 

    New-UDTable -Data $Data -ShowSort -Title 'Sorting'

    New-UDElement -Tag p

    $Data = @(
        @{Dessert = 'Frozen yoghurt'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Ice cream sandwich'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Eclair'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Cupcake'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
        @{Dessert = 'Gingerbread'; Calories = 159; Fat = 6.0; Carbs = 24; Protein = 4.0}
    ) 

    New-UDTable -Id 'service_table' -Data $Data -Title 'Selection' -ShowSearch -ShowPagination -ShowSelection -Dense -OnRowSelection {
        $Item = $EventData
        Show-UDToast -Message "$($Item | out-string)"
    }
    New-UDButton -Text "GET Rows" -OnClick {
        $value = Get-UDElement -Id "service_table"
        Show-UDToast -Message "$( $value.selectedRows | Out-String )"
    }
}

$Pages += New-UDPage -Name 'Tree View' -Content {
    New-UDTreeView -Node {
        New-UDTreeNode -Name 'Level 1' -Children {
            New-UDTreeNode -Name 'Level 2 - Item 1' 
            New-UDTreeNode -Name 'Level 2 - Item 2'
            New-UDTreeNode -Name 'Level 2 - Item 3' -Children {
                New-UDTreeNode -Name 'Level 3'
            }
        }
    }
}

$Pages += New-UDPage -Name 'Typography' -Content {
    @("h1", "h2", "h3", "h4", "h5", "h6", "subtitle1", "subtitle2", "body1", "body2", 
    "caption", "button", "overline", "srOnly", "inherit", 
    "display4", "display3", "display2", "display1", "headline", "title", "subheading") | ForEach-Object {
        New-UDTypography -Variant $_ -Text $_ -GutterBottom
        New-UDElement -Tag 'p' -Content {}
    }
}

$Pages += New-UDPage -Name 'Charts' -Content {
     $Data = Get-Process | Sort-Object -Property CPU -Descending | Select-Object -First 10 
    New-UDChartJS -Type 'bar' -Data $Data -DataProperty CPU -LabelProperty ProcessName

     $Data = Get-Process | Sort-Object -Property CPU -Descending | Select-Object -First 10 
    New-UDChartJS -Type 'bar' -Data $Data -DataProperty CPU -LabelProperty ProcessName

        $GraphPrep = @(
        @{ RAM = "Server1"; AvailableRam = 128; UsedRAM = 10 }
        @{ RAM = "Server2"; AvailableRam = 64; UsedRAM = 63 }
        @{ RAM = "Server3"; AvailableRam = 48; UsedRAM = 40 }
        @{ RAM = "Server4"; AvailableRam = 64;; UsedRAM = 26 }
        @{ RAM = "Server5"; AvailableRam = 128; UsedRAM = 120 }
    )

    $AvailableRamDataSet = New-UDChartJSDataset -DataProperty AvailableRAM -Label 'Available' -BackgroundColor blue
    $UsedRamDataset = New-UDChartJSDataset -DataProperty UsedRAM -Label 'Used' -BackgroundColor red
    $Options = @{
        Type          = 'bar'
        Data          = $GraphPrep
        Dataset       = @($AvailableRamDataSet, $UsedRamDataset)
        LabelProperty = "RAM"
        Options = @{
            scales = @{
                xAxes = @(
                @{
                    stacked = $true
                }
            )
            yAxes = @(
                @{
                    stacked = $true
                }
            )
            }
        }
    } 

    New-UDChartJS @Options

     $Data = Get-Process | Sort-Object -Property CPU -Descending | Select-Object -First 10 
    New-UDChartJS -Type 'horizontalBar' -Data $Data -DataProperty CPU -LabelProperty ProcessName

    $Data = Get-Process | Sort-Object -Property CPU -Descending | Select-Object -First 10 
    New-UDChartJS -Type 'line' -Data $Data -DataProperty CPU -LabelProperty ProcessName

    $Data = Get-Process | Sort-Object -Property CPU -Descending | Select-Object -First 10 
    New-UDChartJS -Type 'doughnut' -Data $Data -DataProperty CPU -LabelProperty ProcessName

    $Data = Get-Process | Sort-Object -Property CPU -Descending | Select-Object -First 10 
    New-UDChartJS -Type 'pie' -Data $Data -DataProperty CPU -LabelProperty ProcessName

     $Data = Get-Process | Sort-Object -Property CPU -Descending | Select-Object -First 10 
    New-UDChartJS -Type 'radar' -Data $Data -DataProperty CPU -LabelProperty ProcessName

     $Data = Get-Process | Sort-Object -Property CPU -Descending | Select-Object -First 10 

    $Options = @{
    Type = 'bar'
    Data = $Data
    BackgroundColor = 'Red'
    BorderColor = '#c61d4a'
    HoverBackgroundColor = 'Blue'
    HoverBorderColor = '#451dc6'
    DataProperty = 'CPU'
    LabelProperty = 'ProcessName'
    }

    New-UDChartJS @Options

    $Data = Get-Process | Sort-Object -Property CPU -Descending | Select-Object -First 10 

    $CPUDataset = New-UDChartJSDataset -DataProperty CPU -Label CPU -BackgroundColor '#126f8c'
    $MemoryDataset = New-UDChartJSDataset -DataProperty HandleCount -Label 'Handle Count' -BackgroundColor '#8da322'

    $Options = @{
    Type = 'bar'
    Data = $Data
    Dataset = @($CPUDataset, $MemoryDataset)
    LabelProperty = "ProcessName"
    }

    New-UDChartJS @Options

     $Data = Get-Process | Sort-Object -Property CPU -Descending | Select-Object -First 10 

    $Options = @{
        Type = 'bar'
        Data = $Data
        DataProperty = 'CPU'
        LabelProperty = "ProcessName"
        OnClick = { 
            Show-UDToast -Message $Body
        }
    }


    New-UDChartJS @Options

    New-UDDynamic -Content {
        $Data = 1..10 | % { 
            [PSCustomObject]@{ Name = $_; value = get-random }
        }
        New-UDChartJS -Type 'bar' -Data $Data -DataProperty Value -Id 'test' -LabelProperty Name -BackgroundColor Blue
    } -AutoRefresh -AutoRefreshInterval 10

    New-UDChartJSMonitor -LoadData {
        Get-Random -Max 100 | Out-UDChartJSMonitorData
    } -Labels "Random" -ChartBackgroundColor "#297741" -RefreshInterval 5

    $Data = 1..10 | ForEach-Object { 
        $item = Get-Random -Max 1000 
        [PSCustomObject]@{
            Name = "Test$item"
            Value = $item
        }
    }
    New-UDNivoChart -Id 'autoRefreshingNivoBar' -Bar -Keys "value" -IndexBy 'name' -Data $Data -Height 500 -Width 1000

    $Data = @(
        @{
            country = 'USA'
            burgers = (Get-Random -Minimum 10 -Maximum 100)
            fries = (Get-Random -Minimum 10 -Maximum 100)
            sandwich = (Get-Random -Minimum 10 -Maximum 100)
        }
        @{
            country = 'Germany'
            burgers = (Get-Random -Minimum 10 -Maximum 100)
            fries = (Get-Random -Minimum 10 -Maximum 100)
            sandwich = (Get-Random -Minimum 10 -Maximum 100)
        }
        @{
            country = 'Japan'
            burgers = (Get-Random -Minimum 10 -Maximum 100)
            fries = (Get-Random -Minimum 10 -Maximum 100)
            sandwich = (Get-Random -Minimum 10 -Maximum 100)
        }
    )

    $Pattern = New-UDNivoPattern -Dots -Id 'dots' -Background "inherit" -Color "#38bcb2" -Size 4 -Padding 1 -Stagger
    $Fill = New-UDNivoFill -ElementId "fries" -PatternId 'dots'

    New-UDNivoChart -Definitions $Pattern -Fill $Fill -Bar -Data $Data -Height 400 -Width 900 -Keys @('burgers', 'fries', 'sandwich')  -IndexBy 'country'

    New-UDDynamic -Content {
    $Data = 1..10 | ForEach-Object { 
            $item = Get-Random -Max 1000 
            [PSCustomObject]@{
                Name = "Test$item"
                Value = $item
            }
        }
        New-UDNivoChart -Id 'autoRefreshingNivoBar' -Bar -Keys "Value" -IndexBy 'name' -Data $Data -Height 500 -Width 1000
    } -AutoRefresh

    $TreeData = @{
        Name     = "root"
        children = @(
            @{
                Name  = "first"
                children = @(
                    @{
                        Name = "first-first"
                        Count = 7
                    }
                    @{
                        Name = "first-second"
                        Count = 8
                    }
                )
            },
            @{
                Name  = "second"
                Count = 21
            }
        )
    }

    New-UDNivoChart -Bubble -Data $TreeData -Value "count" -Identity "name" -Height 500 -Width 800

    $Data = @()
    for($i = 365; $i -gt 0; $i--) {
        $Data += @{
            day = (Get-Date).AddDays($i * -1).ToString("yyyy-MM-dd")
            value = Get-Random
        }
    }

    $From = (Get-Date).AddDays(-365)
    $To = Get-Date

    New-UDNivoChart -Calendar -Data $Data -From $From -To $To -Height 500 -Width 1000 -MarginTop 50 -MarginRight 130 -MarginBottom 50 -MarginLeft 60

    $Data = @(
        @{
            state = "idaho"
            cats = 72307
            dogs = 23429
            moose = 23423
            bears = 784
        }
        @{
            state = "wisconsin"
            cats = 2343342
            dogs = 3453623
            moose = 1
            bears = 23423
        }
        @{
            state = "montana"
            cats = 9234
            dogs = 3973457
            moose = 23472
            bears = 347303
        }
        @{
            state = "colorado"
            cats = 345973789
            dogs = 0237234
            moose = 2302
            bears = 2349772
        }
    )
    New-UDNivoChart -Heatmap -Data $Data -IndexBy 'state' -keys @('cats', 'dogs', 'moose', 'bears')  -Height 500 -Width 1000 -MarginTop 50 -MarginRight 130 -MarginBottom 50 -MarginLeft 60

    [array]$Data = [PSCustomObject]@{
        id = "DataSet"
        data = (1..20 | ForEach-Object {
            $item = Get-Random -Max 500 
            [PSCustomObject]@{
                x = "Test$item"
                y = $item
            }
        })
    }
    New-UDNivoChart -Line -Data $Data -Height 500 -Width 1000 -LineWidth 1

    $Data = 1..10 | ForEach-Object { 
        @{
            "Adam" = Get-Random 
            "Alon" = Get-Random 
            "Lee" = Get-Random 
            "Frank" = Get-Random 
            "Bill" = Get-Random 
        }
    }

    New-UDNivoChart -Stream -Data $Data -Height 500 -Width 1000 -Keys @("adam", "alon", "lee", "frank", "bill")

    $TreeData = @{
        Name     = "root"
        children = @(
            @{
                Name  = "first"
                children = @(
                    @{
                        Name = "first-first"
                        Count = 7
                    }
                    @{
                        Name = "first-second"
                        Count = 8
                    }
                )
            },
            @{
                Name  = "second"
                Count = 21
            }
        )
    }

    New-UDNivoChart -Treemap -Data $TreeData -Value "count" -Identity "name" -Height 500 -Width 800
}

$Pages += New-UDPage -Name 'Map' -Content {
    New-UDMap -Endpoint {
        New-UDMapRasterLayer -TileServer 'https://tiles.wmflabs.org/bw-mapnik/{z}/{x}/{y}.png' 
    } -Latitude 43.52107 -Longitude -114.31644 -Zoom 13 -Height '500px'

    New-UDMap -Endpoint {
        New-UDMapLayerControl -Content {
            New-UDMapBaseLayer -Name 'Black and White' -Content {
                New-UDMapRasterLayer -TileServer 'https://tiles.wmflabs.org/bw-mapnik/{z}/{x}/{y}.png' 
            } -Checked
            New-UDMapBaseLayer -Name 'Color' -Content {
                New-UDMapRasterLayer -TileServer 'https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png' 
            }
            New-UDMapOverlay -Name 'Marker' -Content {
                New-UDMapMarker -Latitude 51.505 -Longitude -0.09 
            } -Checked
            New-UDMapOverlay -Name 'Marker 2' -Content {
                New-UDMapMarker -Latitude 51.555 -Longitude -0.00 
            } -Checked
        }
    } -Latitude 51.505 -Longitude -0.09 -Zoom 13 -Height '500px'

    New-UDMap -Endpoint {
        New-UDMapRasterLayer -TileServer 'https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png' 
        New-UDMapHeatmapLayer -Points @(
            @(-37.9019339833, 175.3879181167, "625"),
            @(-37.90920365, 175.4053418167, "397"),
            @(-37.9057407667, 175.39478875, "540"),
            @(-37.9243174333, 175.4220341833, "112"),
            @(-37.8992012333, 175.3666729333, "815"),
            @(-37.9110874833, 175.4102195833, "360"),
            @(-37.9027096, 175.3913196333, "591"),
            @(-37.9011183833, 175.38410915, "655"),
            @(-37.9234701333, 175.4155696333, "181"),
            @(-37.90254175, 175.3926162167, "582"),
            @(-37.92450575, 175.4246711167, "90"),
            @(-37.9242924167, 175.4289432833, "47"),
            @(-37.8986079833, 175.3685293333, "801")
        )
    } -Height '500px'

    New-UDMap -Endpoint {
        New-UDMapRasterLayer -TileServer 'https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png' 
        New-UDMapMarkerClusterLayer -Id 'cluster-layer' -Markers @(
            1..100 | ForEach-Object {
                $Random = Get-Random -Minimum 0 -Maximum 100
                $RandomLat = $Random + 400
                New-UDMapMarker -Latitude "51.$RandomLat" -Longitude "-0.$Random"
            }
        )
    } -Latitude 51.505 -Longitude -0.09 -Zoom 13 -Height '500px'
}

$Pages += New-UDPage -Name 'Backdrop' -Content {
    New-UDBackdrop -Id 'backdrop' -Content {
        New-UDTypography -Text "Loading..." -Variant h2
    } -Open -OnClick {
        Set-UDElement -Id 'backdrop' -Properties @{
            open = $false
        }
    }
}

$Pages += New-UDPage -Name 'Modal' -Content {
    New-UDButton -Text 'Basic' -OnClick {
        Show-UDModal -Content {
            New-UDTypography -Text "Hello"
        }
    }

    New-UDButton -Text 'Full Screen' -OnClick {
        Show-UDModal -Content {
            New-UDTypography -Text "Hello"
        } -Footer {
            New-UDButton -Text "Close" -OnClick { Hide-UDModal }
        }  -FullScreen
    }

    New-UDButton -Text 'Full Width' -OnClick {
        Show-UDModal -Content {
            New-UDTypography -Text "Hello"
        } -FullWidth -MaxWidth 'md'
    }

    New-UDButton -Text 'Persistent' -OnClick {
        Show-UDModal -Content {
            New-UDTypography -Text "Hello"
        } -Footer {
            New-UDButton -Text "Close" -OnClick { Hide-UDModal }
        } -Persistent
    }

    New-UDButton -Text 'Hide Modal' -OnClick {
        Show-UDModal -Content {
            New-UDTypography -Text "Close in 5..."
        } -Persistent
        Start-Sleep 5
        Hide-UDModal
    } 
}

$Pages += New-UDPage -Name 'Progress' -Content {
    New-UDProgress -Circular -Color Blue
    New-UDProgress
    New-UDProgress -PercentComplete 75
}

$Pages += New-UDPage -Name 'Inputs' -Content {
    New-UDAutocomplete -Options @('Test', 'Test2', 'Test3', 'Test4')
    New-UDAutocomplete -OnLoadOptions { 
        @('Test', 'Test2', 'Test3', 'Test4') | Where-Object { $_ -match $Body } | ConvertTo-Json
    } -OnChange {
        Show-UDToast $Body 
    }
    New-UDButton -Icon (New-UDIcon -Icon trash) -Text 'Delete'
    New-UDButton -Text 'Message Box' -OnClick {
        Show-UDToast -Message 'Hello, world!'
    }
    $Icon = New-UDIcon -Icon angry -Size lg -Regular
    $CheckedIcon = New-UDIcon -Icon angry -Size lg
    New-UDCheckBox -Icon $Icon -CheckedIcon $CheckedIcon -Style @{color = '#2196f3'}

    New-UDCheckBox -OnChange {
        Show-UDToast -Title 'Checkbox' -Message $Body
    }

    New-UDCheckBox -Label 'Demo' -LabelPlacement start
    New-UDCheckBox -Label 'Demo' -LabelPlacement top
    New-UDCheckBox -Label 'Demo' -LabelPlacement bottom
    New-UDCheckBox -Label 'Demo' -LabelPlacement end

    New-UDCodeEditor -Height '500' -Language 'powershell'

    New-UDDatePicker -OnChange {
        Show-UDToast -Message $body
    }
    New-UDDatePicker -Variant static
    New-UDDatePicker -Locale fr
    New-UDFloatingActionButton -Icon (New-UDIcon -Icon user) -Size Small
    New-UDFloatingActionButton -Icon (New-UDIcon -Icon user) -Size Medium
    New-UDFloatingActionButton -Icon (New-UDIcon -Icon user) -Size Large

    New-UDForm -Content {
        New-UDTextbox -Id 'txtTextField'
        New-UDCheckbox -Id 'chkCheckbox'
    } -OnSubmit {
        Show-UDToast -Message $EventData.txtTextField
        Show-UDToast -Message $EventData.chkCheckbox
    }

    New-UDForm -Content {
        New-UDTextbox -Id 'txtValidateForm'
    } -OnValidate {
        $FormContent = $EventData

        if ($FormContent.txtValidateForm -eq $null -or $FormContent.txtValidateForm -eq '') {
            New-UDFormValidationResult -ValidationError "txtValidateForm is required"
        } else {
            New-UDFormValidationResult -Valid
        }
    } -OnSubmit {
        Show-UDToast -Message $Body
    }

    New-UDRadioGroup -Label "Day" -Content {
        New-UDRadio -Label Monday -Value 'monday'
        New-UDRadio -Label Tuesday -Value 'tuesday'
        New-UDRadio -Label Wednesday -Value 'wednesday'
        New-UDRadio -Label Thursday -Value 'thursday'
        New-UDRadio -Label Friday  -Value 'friday'
        New-UDRadio -Label Saturday -Value 'saturday'
        New-UDRadio -Label Sunday -Value 'sunday'
    } -OnChange { Show-UDToast -Message $Body }

    New-UDSelect -Option {
        New-UDSelectOption -Name 'One' -Value 1
        New-UDSelectOption -Name 'Two' -Value 2
        New-UDSelectOption -Name 'Three' -Value 3
    } -OnChange { Show-UDToast -Message $EventData }

    New-UDSlider -OnChange {
        Show-UDToast -Message $Body 
    }

    New-UDSwitch -OnChange { Show-UDToast -Message $EventData }

    New-UDTextbox -Label 'Standard' -Placeholder 'Textbox'
    New-UDTextbox -Label 'Disabled' -Placeholder 'Textbox' -Disabled
    New-UDTextbox -Label 'Textbox' -Value 'With value'

    New-UDTimePicker
    New-UDTimePicker -Locale fr

    New-UDTransferList -Item {
        New-UDTransferListItem -Name 'test1' -Value 1
        New-UDTransferListItem -Name 'test2' -Value 2
        New-UDTransferListItem -Name 'test3' -Value 3
        New-UDTransferListItem -Name 'test4' -Value 4
        New-UDTransferListItem -Name 'test5' -Value 5
    } 

}

$Pages += New-UDPage -Name 'Navigation' -Content {


    New-UDStepper -Steps {
        New-UDStep -OnLoad {
            New-UDElement -tag 'div' -Content { "Step 1" }
            New-UDTextbox -Id 'txtStep1' -Value $EventData.Context.txtStep1
        } -Label "Step 1"
        New-UDStep -OnLoad {
            New-UDElement -tag 'div' -Content { "Step 2" }
            New-UDElement -tag 'div' -Content { "Previous data: $Body" }
            New-UDTextbox -Id 'txtStep2' -Value $EventData.Context.txtStep2
        } -Label "Step 2"
        New-UDStep -OnLoad {
            New-UDElement -tag 'div' -Content { "Step 3" }
            New-UDElement -tag 'div' -Content { "Previous data: $Body" }
            New-UDTextbox -Id 'txtStep3' -Value $EventData.Context.txtStep3
        } -Label "Step 3"
    } -OnFinish {
        New-UDTypography -Text 'Nice! You did it!' -Variant h3
        New-UDElement -Tag 'div' -Id 'result' -Content {$Body}
    }

    New-UDTabs -Tabs {
        New-UDTab -Text 'Item One' -Content { New-UDTypography -Text 'Item One' -Variant 'h2' }
        New-UDTab -Text 'Item Two' -Content { New-UDTypography -Text 'Item Two' -Variant 'h2' }
        New-UDTab -Text 'Item Three' -Content { New-UDTypography -Text 'Item Three' -Variant 'h2' }
    }

    New-UDTabs -Tabs {
        New-UDTab -Text 'Item One' -Content { New-UDTypography -Text 'Item One' -Variant 'h2' }
        New-UDTab -Text 'Item Two' -Content { New-UDTypography -Text 'Item Two' -Variant 'h2' }
        New-UDTab -Text 'Item Three' -Content { New-UDTypography -Text 'Item Three' -Variant 'h2' }
    } -Orientation vertical
}

$Pages += New-UDPage -Name 'Layout' -Content {
    New-UDGrid -Container -Content {
        New-UDGrid -Item -ExtraSmallSize 12 -Content {
            New-UDPaper -Content { "xs-12" } -Elevation 2
        }
        New-UDGrid -Item -ExtraSmallSize 6 -Content {
            New-UDPaper -Content { "xs-6" } -Elevation 2
        }
        New-UDGrid -Item -ExtraSmallSize 6 -Content {
            New-UDPaper -Content { "xs-6" } -Elevation 2
        }
        New-UDGrid -Item -ExtraSmallSize 3 -Content {
            New-UDPaper -Content { "xs-3" } -Elevation 2
        }
        New-UDGrid -Item -ExtraSmallSize 3 -Content {
            New-UDPaper -Content { "xs-3" } -Elevation 2
        }
        New-UDGrid -Item -ExtraSmallSize 3 -Content {
            New-UDPaper -Content { "xs-3" } -Elevation 2
        }
        New-UDGrid -Item -ExtraSmallSize 3 -Content {
            New-UDPaper -Content { "xs-3" } -Elevation 2
        }
    }

    New-UDDynamic -Id 'spacingGrid' -Content {
        $Spacing = (Get-UDElement -Id 'spacingSelect').value

        New-UDGrid -Spacing $Spacing -Container -Content {
            New-UDGrid -Item -ExtraSmallSize 3 -Content {
                New-UDPaper -Content { "xs-3" } -Elevation 2
            }
            New-UDGrid -Item -ExtraSmallSize 3 -Content {
                New-UDPaper -Content { "xs-3" } -Elevation 2
            }
            New-UDGrid -Item -ExtraSmallSize 3 -Content {
                New-UDPaper -Content { "xs-3" } -Elevation 2
            }
            New-UDGrid -Item -ExtraSmallSize 3 -Content {
                New-UDPaper -Content { "xs-3" } -Elevation 2
            }
        }
    }

    New-UDSelect -Id 'spacingSelect' -Label Spacing -Option {
        for($i = 0; $i -lt 10; $i++)
        {
            New-UDSelectOption -Name $i -Value $i
        }
    } -OnChange { Sync-UDElement -Id 'spacingGrid' } -DefaultValue 3
}

$Pages += New-UDpage -Name 'Transitions' -Content {
    New-UDTransition -Id 'test' -Content {
        New-UDCard -Text "Hey"
    } -In -Fade -Timeout 1000

    New-UDSwitch -OnChange {
        Set-UDElement -Id 'test' -Properties @{
            in = $EventData -eq 'True'
        }
    } -Checked $true

    New-UDTransition -Id 'test2' -Content {
        New-UDCard -Text "Hey"
    } -In -Collapse -CollapseHeight 100 -Timeout 1000

    New-UDSwitch -OnChange {
        Set-UDElement -Id 'test2' -Properties @{
            in = $EventData -eq 'True'
        }
    } -Checked $true

    New-UDTransition -Id 'test3' -Content {
        New-UDCard -Text "Hey"
    } -In -Fade -Timeout 1000

    New-UDSwitch -OnChange {
        Set-UDElement -Id 'test3' -Properties @{
            in = $EventData -eq 'True'
        }
    } -Checked $true

    New-UDTransition -Id 'test4' -Content {
        New-UDCard -Text "Hey"
    } -In -Slide -SlideDirection 'left' -Timeout 1000

    New-UDSwitch -OnChange {
        Set-UDElement -Id 'test4' -Properties @{
            in = $EventData -eq 'True'
        }
    } -Checked $true

    New-UDTransition -Id 'test5' -Content {
        New-UDCard -Text "Hey"
    } -In -Grow -Timeout 1000

    New-UDSwitch -OnChange {
        Set-UDElement -Id 'test5' -Properties @{
            in = $EventData -eq 'True'
        }
    } -Checked $true

    New-UDTransition -Id 'test6' -Content {
        New-UDCard -Text "Hey"
    } -In -Zoom -Timeout 1000

    New-UDSwitch -OnChange {
        Set-UDElement -Id 'test6' -Properties @{
            in = $EventData -eq 'True'
        }
    } -Checked $true

}

$Pages += New-UDPage -Name Surfaces -Content {
    New-UDCard -Title 'Simple Card' -Content {
        "This is some content"
    }

    $Header = New-UDCardHeader -Title "Name"

    $Footer = New-UDCardFooter -Content {
        New-UDButton -Variant text -Text 'Stop' -OnClick {
            Show-UDToast -Message 'Stopping VM...' -Duration 5000
            Start-Sleep 5
            Sync-UDElement -Id "Name_card"
        }
    }

    $Body = New-UDCardBody -Content {
        "Info about this VM"
    }

    $Expand = New-UDCardExpand -Content {
        "More info about this VM"
    }

    New-UDStyle -Style '.ud-mu-cardexpand { display: block !important }' -Content {
        New-UDCard -Body $Body -Header $Header -Footer $Footer -Expand $Expand
    }

    New-UDPaper -Elevation 0 -Content {} 
    New-UDPaper -Elevation 1 -Content {} 
    New-UDPaper -Elevation 3 -Content {}
    New-UDPaper -Square -Content {}
    New-UDPaper  -Content { } -Style @{ 
        backgroundColor = 'red'
    }

    New-UDExpansionPanelGroup -Children {
        New-UDExpansionPanel -Title "Hello" -Children {}

        New-UDExpansionPanel -Title "Hello" -Id 'expContent' -Children {
            New-UDElement -Tag 'div' -Content { "Hello" }
        }
    }
}

$Pages += New-UDPage -Name 'Interaction' -Content {
    New-UDButton -Text 'Clipboard' -OnClick {
        Set-UDClipboard -Data 'Hello, there!' -ToastOnSuccess
    }

    New-UDButton -Text 'JavaScript' -OnClick {
        Invoke-UDJavaScript -JavaScript 'alert("Hello!")'
    }

    New-UDButton -Text 'Toast' -OnClick {
        SHow-UDToast "Hey"
    }
}

New-UDDashboard -Title "Universal Dashboard" -Pages $Pages